@@ -13,5 +13,5 @@ app = FastAPI()
 
 
 @app.put("/items/{item_id}")
-async def create_item(item_id: int, item: Item):
+async def update_item(item_id: int, item: Item):
     return {"item_id": item_id, **item.dict()}
