@@ -17,8 +17,6 @@ class User(BaseModel):
 
 
 @app.put("/items/{item_id}")
-async def update_item(
-    item_id: int, item: Item, user: User, importance: int = Body(...)
-):
+async def update_item(item_id: int, item: Item, user: User, importance: int = Body()):
     results = {"item_id": item_id, "item": item, "user": user, "importance": importance}
     return results
