@@ -29,7 +29,7 @@ async def redoc_html():
     return get_redoc_html(
         openapi_url=app.openapi_url,
         title=app.title + " - ReDoc",
-        redoc_js_url="https://unpkg.com/redoc@next/bundles/redoc.standalone.js",
+        redoc_js_url="https://unpkg.com/redoc@2/bundles/redoc.standalone.js",
     )
 
 
