@@ -10,10 +10,10 @@ app = FastAPI()
 @app.put("/items/{item_id}")
 async def read_items(
     item_id: UUID,
-    start_datetime: Annotated[Union[datetime, None], Body()] = None,
-    end_datetime: Annotated[Union[datetime, None], Body()] = None,
+    start_datetime: Annotated[datetime, Body()],
+    end_datetime: Annotated[datetime, Body()],
+    process_after: Annotated[timedelta, Body()],
     repeat_at: Annotated[Union[time, None], Body()] = None,
-    process_after: Annotated[Union[timedelta, None], Body()] = None,
 ):
     start_process = start_datetime + process_after
     duration = end_datetime - start_process
@@ -21,8 +21,8 @@ async def read_items(
         "item_id": item_id,
         "start_datetime": start_datetime,
         "end_datetime": end_datetime,
-        "repeat_at": repeat_at,
         "process_after": process_after,
+        "repeat_at": repeat_at,
         "start_process": start_process,
         "duration": duration,
     }
