@@ -7,6 +7,6 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    strange_header: Annotated[str | None, Header(convert_underscores=False)] = None
+    strange_header: Annotated[str | None, Header(convert_underscores=False)] = None,
 ):
     return {"strange_header": strange_header}
