@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Union
 
 from fastapi import FastAPI, Header
 
@@ -6,5 +6,5 @@ app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(x_token: Optional[list[str]] = Header(None)):
+async def read_items(x_token: Union[list[str], None] = Header(default=None)):
     return {"X-Token values": x_token}
