@@ -5,8 +5,8 @@ app = FastAPI()
 
 @app.get("/items/{item_id}")
 async def read_items(
-    item_id: int = Path(..., title="The ID of the item to get"),
-    q: str | None = Query(None, alias="item-query"),
+    item_id: int = Path(title="The ID of the item to get"),
+    q: str | None = Query(default=None, alias="item-query"),
 ):
     results = {"item_id": item_id}
     if q:
