@@ -7,7 +7,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: Annotated[str | None, Query(min_length=3, max_length=50)] = None
+    q: Annotated[str | None, Query(min_length=3, max_length=50)] = None,
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
