@@ -9,7 +9,7 @@ app = FastAPI()
 async def read_items(
     q: Annotated[
         str | None, Query(min_length=3, max_length=50, pattern="^fixedquery$")
-    ] = None
+    ] = None,
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
