@@ -5,8 +5,9 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: str
-    | None = Query(default=None, min_length=3, max_length=50, pattern="^fixedquery$")
+    q: str | None = Query(
+        default=None, min_length=3, max_length=50, pattern="^fixedquery$"
+    ),
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
