@@ -8,7 +8,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: Annotated[Union[str, None], Query(title="Query string", min_length=3)] = None
+    q: Annotated[Union[str, None], Query(title="Query string", min_length=3)] = None,
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
