@@ -5,13 +5,12 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: str
-    | None = Query(
-        None,
+    q: str | None = Query(
+        default=None,
         title="Query string",
         description="Query string for the items to search in the database that have a good match",
         min_length=3,
-    )
+    ),
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
