@@ -5,8 +5,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: str
-    | None = Query(
+    q: str | None = Query(
         default=None,
         alias="item-query",
         title="Query string",
@@ -15,7 +14,7 @@ async def read_items(
         max_length=50,
         pattern="^fixedquery$",
         deprecated=True,
-    )
+    ),
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
