@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Union
 
 from fastapi import FastAPI, Query
 
@@ -6,6 +6,6 @@ app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(q: Optional[list[str]] = Query(None)):
+async def read_items(q: Union[list[str], None] = Query(default=None)):
     query_items = {"q": q}
     return query_items
