@@ -8,7 +8,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    hidden_query: Annotated[Union[str, None], Query(include_in_schema=False)] = None
+    hidden_query: Annotated[Union[str, None], Query(include_in_schema=False)] = None,
 ):
     if hidden_query:
         return {"hidden_query": hidden_query}
