@@ -4,7 +4,7 @@ app = FastAPI()
 
 
 @app.post("/files/")
-async def create_file(file: bytes = File(...)):
+async def create_file(file: bytes = File()):
     return {"file_size": len(file)}
 
 
