@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Any, Union
 
 from fastapi import FastAPI
 from pydantic import BaseModel
@@ -15,5 +15,13 @@ class Item(BaseModel):
 
 
 @app.post("/items/", response_model=Item)
-async def create_item(item: Item):
+async def create_item(item: Item) -> Any:
     return item
+
+
+@app.get("/items/", response_model=list[Item])
+async def read_items() -> Any:
+    return [
+        {"name": "Portal Gun", "price": 42.0},
+        {"name": "Plumbus", "price": 32.0},
+    ]
