@@ -15,12 +15,14 @@ class Item(BaseModel):
 async def update_item(
     item_id: int,
     item: Item = Body(
-        example={
-            "name": "Foo",
-            "description": "A very nice Item",
-            "price": 35.4,
-            "tax": 3.2,
-        },
+        examples=[
+            {
+                "name": "Foo",
+                "description": "A very nice Item",
+                "price": 35.4,
+                "tax": 3.2,
+            }
+        ],
     ),
 ):
     results = {"item_id": item_id, "item": item}
