@@ -3,7 +3,6 @@ from typing import List
 from dirty_equals import IsDict
 from fastapi import FastAPI, Query
 from fastapi.testclient import TestClient
-from fastapi.utils import match_pydantic_error_url
 
 app = FastAPI()
 
@@ -33,14 +32,12 @@ def test_multi_query_incorrect():
                     "loc": ["query", "q", 0],
                     "msg": "Input should be a valid integer, unable to parse string as an integer",
                     "input": "five",
-                    "url": match_pydantic_error_url("int_parsing"),
                 },
                 {
                     "type": "int_parsing",
                     "loc": ["query", "q", 1],
                     "msg": "Input should be a valid integer, unable to parse string as an integer",
                     "input": "six",
-                    "url": match_pydantic_error_url("int_parsing"),
                 },
             ]
         }
