@@ -1,14 +1,24 @@
+import importlib
+
 import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
-from fastapi.utils import match_pydantic_error_url
+
+from ...utils import needs_py39
 
 
-@pytest.fixture(name="client")
-def get_client():
-    from docs_src.bigger_applications.app.main import app
+@pytest.fixture(
+    name="client",
+    params=[
+        "app_an.main",
+        pytest.param("app_an_py39.main", marks=needs_py39),
+        "app.main",
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.bigger_applications.{request.param}")
 
-    client = TestClient(app)
+    client = TestClient(mod.app)
     return client
 
 
@@ -29,7 +39,6 @@ def test_users_with_no_token(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -64,7 +73,6 @@ def test_users_foo_with_no_token(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -99,7 +107,6 @@ def test_users_me_with_no_token(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -145,7 +152,6 @@ def test_items_with_no_token_jessica(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -192,7 +198,6 @@ def test_items_plumbus_with_no_token(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -233,7 +238,6 @@ def test_items_with_missing_x_token_header(client: TestClient):
                     "loc": ["header", "x-token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -262,7 +266,6 @@ def test_items_plumbus_with_missing_x_token_header(client: TestClient):
                     "loc": ["header", "x-token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -297,7 +300,6 @@ def test_root_with_no_token(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -326,14 +328,12 @@ def test_put_no_header(client: TestClient):
                     "loc": ["query", "token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
                 {
                     "type": "missing",
                     "loc": ["header", "x-token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
             ]
         }
