@@ -1,13 +1,28 @@
+import importlib
+
+import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
-from fastapi.utils import match_pydantic_error_url
 
-from docs_src.dependencies.tutorial012 import app
-
-client = TestClient(app)
+from ...utils import needs_py39
 
 
-def test_get_no_headers_items():
+@pytest.fixture(
+    name="client",
+    params=[
+        "tutorial012",
+        "tutorial012_an",
+        pytest.param("tutorial012_an_py39", marks=needs_py39),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.dependencies.{request.param}")
+
+    client = TestClient(mod.app)
+    return client
+
+
+def test_get_no_headers_items(client: TestClient):
     response = client.get("/items/")
     assert response.status_code == 422, response.text
     assert response.json() == IsDict(
@@ -18,14 +33,12 @@ def test_get_no_headers_items():
                     "loc": ["header", "x-token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
                 {
                     "type": "missing",
                     "loc": ["header", "x-key"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
             ]
         }
@@ -48,7 +61,7 @@ def test_get_no_headers_items():
     )
 
 
-def test_get_no_headers_users():
+def test_get_no_headers_users(client: TestClient):
     response = client.get("/users/")
     assert response.status_code == 422, response.text
     assert response.json() == IsDict(
@@ -59,14 +72,12 @@ def test_get_no_headers_users():
                     "loc": ["header", "x-token"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
                 {
                     "type": "missing",
                     "loc": ["header", "x-key"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 },
             ]
         }
@@ -89,19 +100,19 @@ def test_get_no_headers_users():
     )
 
 
-def test_get_invalid_one_header_items():
+def test_get_invalid_one_header_items(client: TestClient):
     response = client.get("/items/", headers={"X-Token": "invalid"})
     assert response.status_code == 400, response.text
     assert response.json() == {"detail": "X-Token header invalid"}
 
 
-def test_get_invalid_one_users():
+def test_get_invalid_one_users(client: TestClient):
     response = client.get("/users/", headers={"X-Token": "invalid"})
     assert response.status_code == 400, response.text
     assert response.json() == {"detail": "X-Token header invalid"}
 
 
-def test_get_invalid_second_header_items():
+def test_get_invalid_second_header_items(client: TestClient):
     response = client.get(
         "/items/", headers={"X-Token": "fake-super-secret-token", "X-Key": "invalid"}
     )
@@ -109,7 +120,7 @@ def test_get_invalid_second_header_items():
     assert response.json() == {"detail": "X-Key header invalid"}
 
 
-def test_get_invalid_second_header_users():
+def test_get_invalid_second_header_users(client: TestClient):
     response = client.get(
         "/users/", headers={"X-Token": "fake-super-secret-token", "X-Key": "invalid"}
     )
@@ -117,7 +128,7 @@ def test_get_invalid_second_header_users():
     assert response.json() == {"detail": "X-Key header invalid"}
 
 
-def test_get_valid_headers_items():
+def test_get_valid_headers_items(client: TestClient):
     response = client.get(
         "/items/",
         headers={
@@ -129,7 +140,7 @@ def test_get_valid_headers_items():
     assert response.json() == [{"item": "Portal Gun"}, {"item": "Plumbus"}]
 
 
-def test_get_valid_headers_users():
+def test_get_valid_headers_users(client: TestClient):
     response = client.get(
         "/users/",
         headers={
@@ -141,7 +152,7 @@ def test_get_valid_headers_users():
     assert response.json() == [{"username": "Rick"}, {"username": "Morty"}]
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
