@@ -1,12 +1,30 @@
+import importlib
+
+import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from docs_src.extra_data_types.tutorial001 import app
-
-client = TestClient(app)
+from ...utils import needs_py39, needs_py310
 
 
-def test_extra_types():
+@pytest.fixture(
+    name="client",
+    params=[
+        "tutorial001",
+        pytest.param("tutorial001_py310", marks=needs_py310),
+        "tutorial001_an",
+        pytest.param("tutorial001_an_py39", marks=needs_py39),
+        pytest.param("tutorial001_an_py310", marks=needs_py310),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.extra_data_types.{request.param}")
+
+    client = TestClient(mod.app)
+    return client
+
+
+def test_extra_types(client: TestClient):
     item_id = "ff97dd87-a4a5-4a12-b412-cde99f33e00e"
     data = {
         "start_datetime": "2018-12-22T14:00:00+00:00",
@@ -27,7 +45,7 @@ def test_extra_types():
     assert response.json() == expected_response
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
@@ -67,6 +85,7 @@ def test_openapi_schema():
                         }
                     ],
                     "requestBody": {
+                        "required": True,
                         "content": {
                             "application/json": {
                                 "schema": IsDict(
@@ -86,7 +105,7 @@ def test_openapi_schema():
                                     }
                                 )
                             }
-                        }
+                        },
                     },
                 }
             }
@@ -97,40 +116,16 @@ def test_openapi_schema():
                     "title": "Body_read_items_items__item_id__put",
                     "type": "object",
                     "properties": {
-                        "start_datetime": IsDict(
-                            {
-                                "title": "Start Datetime",
-                                "anyOf": [
-                                    {"type": "string", "format": "date-time"},
-                                    {"type": "null"},
-                                ],
-                            }
-                        )
-                        | IsDict(
-                            # TODO: remove when deprecating Pydantic v1
-                            {
-                                "title": "Start Datetime",
-                                "type": "string",
-                                "format": "date-time",
-                            }
-                        ),
-                        "end_datetime": IsDict(
-                            {
-                                "title": "End Datetime",
-                                "anyOf": [
-                                    {"type": "string", "format": "date-time"},
-                                    {"type": "null"},
-                                ],
-                            }
-                        )
-                        | IsDict(
-                            # TODO: remove when deprecating Pydantic v1
-                            {
-                                "title": "End Datetime",
-                                "type": "string",
-                                "format": "date-time",
-                            }
-                        ),
+                        "start_datetime": {
+                            "title": "Start Datetime",
+                            "type": "string",
+                            "format": "date-time",
+                        },
+                        "end_datetime": {
+                            "title": "End Datetime",
+                            "type": "string",
+                            "format": "date-time",
+                        },
                         "repeat_at": IsDict(
                             {
                                 "title": "Repeat At",
@@ -151,10 +146,8 @@ def test_openapi_schema():
                         "process_after": IsDict(
                             {
                                 "title": "Process After",
-                                "anyOf": [
-                                    {"type": "string", "format": "duration"},
-                                    {"type": "null"},
-                                ],
+                                "type": "string",
+                                "format": "duration",
                             }
                         )
                         | IsDict(
@@ -166,6 +159,7 @@ def test_openapi_schema():
                             }
                         ),
                     },
+                    "required": ["start_datetime", "end_datetime", "process_after"],
                 },
                 "ValidationError": {
                     "title": "ValidationError",
