@@ -16,7 +16,10 @@ def test_main():
     client = TestClient(app)
     response = client.get("/items/foo")
     assert response.status_code == 200, response.text
-    assert b"<h1>Item ID: foo</h1>" in response.content
+    assert (
+        b'<h1><a href="http://testserver/items/foo">Item ID: foo</a></h1>'
+        in response.content
+    )
     response = client.get("/static/styles.css")
     assert response.status_code == 200, response.text
     assert b"color: green;" in response.content
